@@ -26,8 +26,8 @@ __version__ = "$Id: db.py 309 2007-04-09 16:23:38Z wrobel $"
 
 import os, codecs, os.path, urllib2, re, hashlib
 
-from   layman.utils             import path
-from   layman.overlay           import Overlays
+from   layman.utils             import path, delete_empty_directory
+from   layman.dbbase            import DbBase, UnknownOverlayException
 
 from   layman.debug             import OUT
 
@@ -37,7 +37,7 @@ from   layman.debug             import OUT
 #
 #-------------------------------------------------------------------------------
 
-class DB(Overlays):
+class DB(DbBase):
     ''' Handle the list of local overlays.'''
 
     def __init__(self, config):
@@ -53,7 +53,7 @@ class DB(Overlays):
 
         quiet = int(config['quietness']) < 3
 
-        Overlays.__init__(self, 
+        DbBase.__init__(self,
                           [config['local_list'], ],
                           config,
                           ignore, 
@@ -90,7 +90,7 @@ class DB(Overlays):
 
         # >>> b.add(a.select('wrobel-stable')) #doctest: +ELLIPSIS
         # * Running command "/usr/bin/rsync -rlptDvz --progress --delete --delete-after --timeout=180 --exclude="distfiles/*" --exclude="local/*" --exclude="packages/*" "rsync://gunnarwrobel.de/wrobel-stable/*" "/tmp/file.../wrobel-stable""...
-        # >>> c = Overlays([write, ], dict())
+        # >>> c = DbBase([write, ], dict())
         # >>> c.overlays.keys()
         # [u'wrobel-stable']
 
@@ -116,11 +116,16 @@ class DB(Overlays):
                 make_conf = MakeConf(self.config, self.overlays)
                 make_conf.add(overlay)
             else:
-                raise Exception('Adding the overlay failed! Possible remains of'
-                                ' the operation have NOT been removed and may b'
-                                'e left at ' + path([self.config['storage'],
-                                                  overlay.name]) + '. Please re'
-                                'move them manually if required.')
+                mdir = path([self.config['storage'], overlay.name])
+                delete_empty_directory(mdir)
+                if os.path.exists(mdir):
+                    raise Exception('Adding overlay "%s" failed!'
+                                ' Possible remains of the operation have NOT'
+                                ' been removed and may be left at "%s".'
+                                ' Please remove them manually if required.' \
+                                % (overlay.name, mdir))
+                else:
+                    raise Exception('Adding overlay "%s" failed!' % overlay.name)
         else:
             raise Exception('Overlay "' + overlay.name + '" already in the loca'
                             'l list!')
@@ -157,12 +162,12 @@ class DB(Overlays):
         # * Running command "/usr/bin/rsync -rlptDvz --progress --delete --delete-after --timeout=180 --exclude="distfiles/*" --exclude="local/*" --exclude="packages/*" "rsync://gunnarwrobel.de/wrobel-stable/*" "/tmp/file.../wrobel-stable""...
         # >>> b.add(a.select('wrobel')) #doctest: +ELLIPSIS
         # * Running command "/usr/bin/svn co "https://overlays.gentoo.org/svn/dev/wrobel/" "/tmp/file.../wrobel""...
-        # >>> c = Overlays([write, ], dict())
+        # >>> c = DbBase([write, ], dict())
         # >>> c.overlays.keys()
         # [u'wrobel', u'wrobel-stable']
 
         # >>> b.delete(b.select('wrobel'))
-        # >>> c = Overlays([write, ], dict())
+        # >>> c = DbBase([write, ], dict())
         # >>> c.overlays.keys()
         # [u'wrobel-stable']
 
@@ -189,15 +194,11 @@ class DB(Overlays):
     def sync(self, overlay_name, quiet = False):
         '''Synchronize the given overlay.'''
 
-        overlay = self.select(overlay_name)
-
-        if overlay:
-            result = overlay.sync(self.config['storage'], quiet)
-            if result:
-                raise Exception('Syncing overlay "' + overlay_name + 
-                                '" returned status ' + str(result) + '!')
-        else:
-            raise Exception('No such overlay ("' + overlay_name + '")!')
+        overlay = self.select(overlay_name) # UnknownOverlayException
+        result = overlay.sync(self.config['storage'], quiet)
+        if result:
+            raise Exception('Syncing overlay "' + overlay_name +
+                            '" returned status ' + str(result) + '!')
 
 #===============================================================================
 #
@@ -205,7 +206,7 @@ class DB(Overlays):
 #
 #-------------------------------------------------------------------------------
 
-class RemoteDB(Overlays):
+class RemoteDB(DbBase):
     '''Handles fetching the remote overlay list.'''
 
     def __init__(self, config):
@@ -235,7 +236,7 @@ class RemoteDB(Overlays):
 
         quiet = int(config['quietness']) < 3
 
-        Overlays.__init__(self, paths, config, ignore, quiet)
+        DbBase.__init__(self, paths, config, ignore, quiet)
 
     def cache(self):
         '''
