@@ -25,7 +25,7 @@ __version__ = "$Id: svn.py 236 2006-09-05 20:39:37Z wrobel $"
 #-------------------------------------------------------------------------------
 
 from   layman.utils             import path
-from   layman.overlays.overlay  import Overlay
+from   layman.overlays.source   import OverlaySource
 
 #===============================================================================
 #
@@ -33,22 +33,22 @@ from   layman.overlays.overlay  import Overlay
 #
 #-------------------------------------------------------------------------------
 
-class SvnOverlay(Overlay):
+class SvnOverlay(OverlaySource):
     ''' Handles subversion overlays.'''
 
     type = 'Subversion'
     type_key = 'svn'
 
-    def __init__(self, xml, config, ignore = 0, quiet = False):
+    def __init__(self, parent, xml, config, _location, ignore = 0, quiet = False):
 
-        Overlay.__init__(self, xml, config, ignore)
+        super(SvnOverlay, self).__init__(parent, xml, config, _location, ignore, quiet)
 
     def add(self, base, quiet = False):
         '''Add overlay.'''
 
         self.supported()
 
-        Overlay.add(self, base)
+        super(SvnOverlay, self).add(base)
 
         if quiet:
             quiet_option = '-q '
@@ -56,7 +56,7 @@ class SvnOverlay(Overlay):
             quiet_option = ''
 
         return self.cmd(self.command() + ' co ' + quiet_option +
-                        '"' + self.src + '/@" "' + path([base, self.name]) + '"')
+                        '"' + self.src + '/@" "' + path([base, self.parent.name]) + '"')
 
     def sync(self, base, quiet = False):
         '''Sync overlay.'''
@@ -69,10 +69,10 @@ class SvnOverlay(Overlay):
             quiet_option = ''
 
         return self.cmd(self.command() + ' up ' + quiet_option +
-                        '"' + path([base, self.name + '@']) + '"')
+                        '"' + path([base, self.parent.name + '@']) + '"')
 
     def supported(self):
         '''Overlay type supported?'''
 
-        return Overlay.supported(self, [(self.command(),  'svn',
+        return super(SvnOverlay, self).supported([(self.command(),  'svn',
                                          'dev-util/subversion'),])
